==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/Input/vorbis/translations/vorbis_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="50"/>
        <source>Ogg Vorbis Plugin</source>
        <translation>Ogg Vorbis Eklentisi</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="53"/>
        <source>Ogg Vorbis Files</source>
        <translation>Ogg Vorbis Dosyaları</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="124"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation>Ogg Vorbis Ses Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="125"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation>Qmmp Ogg Vorbis Ses Eklentisi</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="126"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="127"/>
        <source>Source code based on mq3 progect</source>
        <translation>Kaynak kodu mq3 projesi temellidir</translation>
    </message>
</context>
<context>
    <name>VorbisMetaDataModel</name>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="51"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Hz</source>
        <translation type="unfinished">Hz</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="53"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>kbps</source>
        <translation type="unfinished">kbps</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>KB</source>
        <translation type="unfinished">KB</translation>
    </message>
</context>
</TS>

==> qmmp_0.5.2.orig.tar.gz: qmmp-0.5.2/src/plugins/Input/vorbis/translations/vorbis_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="50"/>
        <source>Ogg Vorbis Plugin</source>
        <translation>Ogg Vorbis Eklentisi</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="53"/>
        <source>Ogg Vorbis Files</source>
        <translation>Ogg Vorbis Dosyaları</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="124"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation>Ogg Vorbis Ses Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="125"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation>Qmmp Ogg Vorbis Ses Eklentisi</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="126"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="127"/>
        <source>Source code based on mq3 progect</source>
        <translation>Kaynak kodu mq3 projesi temellidir</translation>
    </message>
</context>
<context>
    <name>VorbisMetaDataModel</name>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="51"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Hz</source>
        <translation type="unfinished">Hz</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="53"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>kbps</source>
        <translation type="unfinished">kbps</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>KB</source>
        <translation type="unfinished">KB</translation>
    </message>
</context>
</TS>
